@@ -109,6 +109,14 @@ class ParticleData(object):
         return s
 
 
+## Add PID functions to the ParticleData object as bound methods
+import pypdt.pid as _PID
+for symname in dir(_PID):
+    if not symname.startswith("_") and not symname.startswith("N"):
+        ## Note lambda binding / lexical closure trick with sym=
+        f = lambda self, sym=getattr(_PID, symname) : sym(self.id)
+        setattr(ParticleData, symname, f)
+
 
 class ParticleDataTable(object):
     """
@@ -123,7 +131,7 @@ class ParticleDataTable(object):
         """
         Constructor, taking the path to the PDT database file as an argument.
         If no arg is supplied, or it is None, try to find and load the version
-        installed by the package, or fall back to look on CERN AFS.
+        installed by the package, or fall back to look at $PYPDT_DB or on CERN AFS.
         """
         import os
         if dbpath is None:
@@ -133,7 +141,10 @@ class ParticleDataTable(object):
                 prefix = os.path.dirname(prefix)
             dbpath = os.path.join(prefix, "share", "pypdt", "particle.tbl")
             if not os.path.exists(dbpath):
-                dbpath = "/afs/cern.ch/sw/lcg/external/HepPDT/3.04.01/src/HepPDT-3.04.01/data/particle.tbl"
+                if os.environ.has_key("PYPDT_DB"):
+                    dbpath = os.environ["PYPDT_DB"]
+                else:
+                    dbpath = "/afs/cern.ch/sw/lcg/external/HepPDT/3.04.01/src/HepPDT-3.04.01/data/particle.tbl"
         self.clear()
         self.read_db(dbpath)
 
@@ -186,3 +197,5 @@ class ParticleDataTable(object):
 
 "Super-short alias for the rather lengthy ParticleDataTable class"
 PDT = ParticleDataTable
+
+#print "#", PDT()[2212].isValid(), PDT()[2212].threeCharge(), PDT()[2212].charge()
